#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2012 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#Source the Migration Param file.
. $1
DB2_CMD=$DB2_BIN_PATH/db2

DIRHOME=$2
DB2HOME=$(cat /etc/passwd | grep $DB_USER | awk -F':' '{print $6}')
. $DB2HOME/sqllib/db2profile

	echo "Getting Tablespace ids..."

    #Initialize the tablespace key ids to an invalid value.
	TPCTBSPKEYSID=-1
	TPCTBSPPMID=-1
	TPCTBSPTEMPID=-1
	TPCTBSPDATAID=-1
	TPCTBSPUSRTMPID=-1


    #Get the tablespace key ids.
    TPCTBSPKEYSID=$(cat $BACKUP_DIR/Tablespaces.txt|grep TPCTBSPKEYS|awk -F" " '{print $2}')
    TPCTBSPPMID=$(cat $BACKUP_DIR/Tablespaces.txt|grep TPCTBSPPM|awk -F" " '{print $2}')
    TPCTBSPTEMPID=$(cat $BACKUP_DIR/Tablespaces.txt|grep TPCTBSPTEMP|awk -F" " '{print $2}')
    TPCTBSPDATAID=$(cat $BACKUP_DIR/Tablespaces.txt|grep TPCTBSPDATA|awk -F" " '{print $2}')
    TPCTBSPUSRTMPID=$(cat $BACKUP_DIR/Tablespaces.txt|grep TPCTBSPUSRTMP|awk -F" " '{print $2}')

    #Display the tablespace key ids in the log.
	echo "TPCTBSPKEYSID=$TPCTBSPKEYSID"
	echo "TPCTBSPPMID=$TPCTBSPPMID"
	echo "TPCTBSPTEMPID=$TPCTBSPTEMPID"
	echo "TPCTBSPDATAID=$TPCTBSPDATAID"
	echo "TPCTBSPUSRTMPID=$TPCTBSPUSRTMPID"
    
    
    #Check to make sure all the tablespace keys were found.
    if [ "$TPCTBSPKEYSID" == "-1" ] ; then
    	echo "Error getting TPCTBSPKeys tablespace id"
    	exit 1
    fi

    if [ "$TPCTBSPPMID" == "-1" ] ; then
    	echo "Error getting TPCTBSPPM tablespace id"
    	exit 1
    fi
    
	if [ "$TPCTBSPTEMPID" == "-1" ] ; then
    	echo "Error getting TPCTBSPTEMP tablespace id"
    	exit 1
    fi
    
        if [ "$TPCTBSPDATAID" == "-1" ] ; then
    	echo "Error getting TPCTBSPDATA tablespace id"
    	exit 1
    fi
    
        if [ "$TPCTBSPUSRTMPID" == "-1" ] ; then
    	echo "Error getting TPCTBSPUSRTMP tablespace id"
    	exit 1
    fi

#Write the DB2 commands to a file.
#For the redirected restore database operation, it will only work if all 
#the restore commands are executed from within the first connection to the 
#database after the restore command is issued.  Having to sudo to the db2
#userid for each command will cause a new connection to the database.
#Hence, we write all the DB2 commands to a file, and then execute them
#all under a single sudo operation.

DB2_CMD_FILE=$BACKUP_DIR/DB2RestoreCommands
echo "" > $DB2_CMD_FILE
echo "echo Executing redirected restore of database $DB_NAME..." >> $DB2_CMD_FILE
echo "RESTORE DATABASE $DB_NAME USER $DB_USER USING $DB_PASSWORD FROM $BACKUP_DIR on $DB2HOME $TAKEN_AT WITH 2 BUFFERS BUFFER 1024 REDIRECT PARALLELISM 1 WITHOUT ROLLING FORWARD WITHOUT PROMPTING" >> $DB2_CMD_FILE
echo "echo Setting tablespace containers for TPCTBSPKeys..." >> $DB2_CMD_FILE
echo "set tablespace containers for $TPCTBSPKEYSID using (path '$DB2HOME/$DB_USER/TPCDB/TPC/TPCTBSPKeys')" >> $DB2_CMD_FILE
echo "echo Setting tablespace containers for TPCTBSPPM..." >> $DB2_CMD_FILE
echo "set tablespace containers for $TPCTBSPPMID using (path '$DB2HOME/$DB_USER/TPCDB/TPC/TPCTBSPPM')" >> $DB2_CMD_FILE
echo "echo Setting tablespace containers for TPCTBSPTEMP..." >> $DB2_CMD_FILE
echo "set tablespace containers for $TPCTBSPTEMPID using (path '$DB2HOME/$DB_USER/TPCDB/TPC/TPCTBSPTEMP')" >> $DB2_CMD_FILE
echo "echo Setting tablespace containers for TPCTBSPData..." >> $DB2_CMD_FILE
echo "set tablespace containers for $TPCTBSPDATAID using (path '$DB2HOME/$DB_USER/TPCDB/TPC/TPCTBSPData')" >> $DB2_CMD_FILE
echo "echo Setting tablespace containers for TPCTBSPUSRTMP..." >> $DB2_CMD_FILE
echo "set tablespace containers for $TPCTBSPUSRTMPID using (path '$DB2HOME/$DB_USER/TPCDB/TPC/TPCTBSPUSRTMP')" >> $DB2_CMD_FILE
echo "echo Continuing restore of database $DB_NAME..." >> $DB2_CMD_FILE
echo "restore db TPCDB continue" >> $DB2_CMD_FILE


#Run DB2 commands listed in the DB2 Command file.
#The -v option turns on verbose output, so we can see individual commands, responses, and errors.
#The -s option stops processing when an error occurs.  If a error occurs, the return code will be the return code of the failed command.
#The -f option requests that we run DB2 commands from an input file.
su - $DB_USER -c "$DB2_CMD -vsf $DB2_CMD_FILE"
if [ $? != 0 -a $? != 2 ] ; then
   echo "Storage Control database restore commands failed."
   exit 1
fi

rm $DB2_CMD_FILE

echo "Restore completed"
exit 0

